==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/tr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sunucudan sunucuya paylaşım bu sunucuda etkin değil",
    "The mountpoint name contains invalid characters." : "Bağlama noktası adı geçersiz karakterler içeriyor.",
    "Invalid or untrusted SSL certificate" : "Geçersiz veya güvenilmeyen SSL sertifikası",
    "Could not authenticate to remote share, password might be wrong" : "Uzak paylaşım kimliği doğrulanamadı, parola hatalı olabilir",
    "Storage not valid" : "Depolama geçerli değil",
    "Couldn't add remote share" : "Uzak paylaşım eklenemedi",
    "Shared with you" : "Sizinle paylaşılmış",
    "Shared with others" : "Diğerleri ile paylaşılmış",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Nothing shared with you yet" : "Sizinle henüz hiçbir şey paylaşılmamış",
    "Files and folders others share with you will show up here" : "Sizinle paylaşılan dosya ve klasörler burada gösterilecek",
    "Nothing shared yet" : "Henüz hiçbir şey paylaşılmamış",
    "Files and folders you share will show up here" : "Paylaştığınız dosya ve klasörler burada gösterilecek",
    "No shared links" : "Paylaşılan bağlantı yok",
    "Files and folders you share by link will show up here" : "Bağlantı ile paylaştığınız dosya ve klasörler burada gösterilecek",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
    "Remote share" : "Uzak paylaşım",
    "Remote share password" : "Uzak paylaşım parolası",
    "Cancel" : "İptal",
    "Add remote share" : "Uzak paylaşım ekle",
    "You can upload into this folder" : "Bu dizine yükleme yapabilirsiniz",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote} üzerinde ownCloud (7 veya daha üstü) kurulumu bulunamadı",
    "Invalid ownCloud url" : "Geçersiz ownCloud adresi",
    "Shared by" : "Paylaşan",
    "Sharing" : "Paylaşım",
    "A file or folder has been <strong>shared</strong>" : "Bir dosya veya klasör <strong>paylaşıldı</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Başka sunucudan</strong> bir dosya veya klasör paylaşıldı",
    "A public shared file or folder was <strong>downloaded</strong>" : "Herkese açık paylaşılan bir dosya veya klasör <strong>indirildi</strong>",
    "You received a new remote share %2$s from %1$s" : "%1$s kişisinden, %2$s uzak paylaşımını aldınız",
    "You received a new remote share from %s" : "%s kişisinden yeni bir uzak paylaşım aldınız",
    "%1$s accepted remote share %2$s" : "%1$s, %2$s uzak paylaşımını kabul etti",
    "%1$s declined remote share %2$s" : "%1$s, %2$s uzak paylaşımını reddetti",
    "%1$s unshared %2$s from you" : "%1$s, sizinle %2$s paylaşımını durdurdu",
    "Public shared folder %1$s was downloaded" : "Herkese açık paylaşılan klasör %1$s indirildi",
    "Public shared file %1$s was downloaded" : "Herkese açık paylaşılan dosya %1$s indirildi",
    "You shared %1$s with %2$s" : "%1$s dosyasını %2$s ile paylaştınız",
    "You shared %1$s with group %2$s" : "%1$s dosyasını %2$s grubu ile paylaştınız",
    "%2$s shared %1$s with %3$s" : "%2$s %3$s ile %1$s dosyasını paylaştı",
    "%2$s shared %1$s with group %3$s" : "%2$s %3$s grubu ile %1$s dosyasını paylaştı",
    "%2$s shared %1$s via link" : "%2$s bağlantı ile %1$s dosyasını paylaştı",
    "%2$s shared %1$s with you" : "%2$s sizinle %1$s dosyasını paylaştı",
    "You shared %1$s via link" : "Bağlantı ile %1$s paylaşımını yaptınız",
    "Downloaded via public link" : "Herkese açık bağlantı ile indirildi",
    "Shared with %2$s" : "%2$s ile paylaşıldı",
    "Shared with group %2$s" : "%2$s grubu ile paylaşıldı",
    "Shared with %3$s by %2$s" : "%3$s ile %2$s tarafından paylaşıldı",
    "Shared with group %3$s by %2$s" : "%2$s tarafından %3$s grubu ile paylaşıldı",
    "Shared via link by %2$s" : "%2$s tarafından bağlantı ile paylaşıldı",
    "Shared by %2$s" : "%2$s tarafından paylaşıldı",
    "Shared via public link" : "Herkese açık bağlantı ile paylaşıldı",
    "Shares" : "Paylaşımlar",
    "You received %2$s as a remote share from %1$s" : "%1$s kişisinden %2$s paylaşımını uzak paylaşım olarak aldınız",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud Birleşik Bulut kimliğim ile paylaşıldı, bkz %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud Birleşmiş Bulut kimliğim ile paylaşıldı",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong. Try again." : "Parola hatalı. Yeniden deneyin.",
    "Password" : "Parola",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Name" : "Ad",
    "Share time" : "Paylaşma zamanı",
    "Sorry, this link doesn’t seem to work anymore." : "Üzgünüz, bu bağlantı artık çalışıyor gibi görünmüyor.",
    "Reasons might be:" : "Sebepleri şunlar olabilir:",
    "the item was removed" : "öge kaldırılmış",
    "the link expired" : "bağlantı süresi dolmuş",
    "sharing is disabled" : "paylaşım devre dışı",
    "For more info, please ask the person who sent this link." : "Daha fazla bilgi için bu bağlantıyı aldığınız kişi ile iletişime geçin.",
    "Add to your ownCloud" : "ownCloud'ınıza Ekleyin",
    "Download" : "İndir",
    "Download %s" : "İndir: %s",
    "Direct link" : "Doğrudan bağlantı",
    "Federated Cloud Sharing" : "Birleşmiş Bulut Paylaşımı",
    "Open documentation" : "Belgelendirmeyi aç",
    "Allow users on this server to send shares to other servers" : "Bu sunucudaki kullanıcıların diğer sunuculara paylaşım göndermelerine izin ver",
    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcıların diğer sunuculardan paylaşım almalarına izin ver",
    "Federated Cloud" : "Birleşmiş Bulut",
    "Your Federated Cloud ID:" : "Birleşmiş Bulut Kimliğiniz:",
    "Share it:" : "Paylaşın:",
    "Add to your website" : "Web sitenize ekleyin",
    "Share with me via ownCloud" : "Benimle ownCloud aracılığıyla paylaşıldı",
    "HTML Code:" : "HTML Kodu:"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/tr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sunucudan sunucuya paylaşım bu sunucuda etkin değil",
    "The mountpoint name contains invalid characters." : "Bağlama noktası adı geçersiz karakterler içeriyor.",
    "Not allowed to create a federated share with the same user server" : "Aynı sunucuda kullanıcılarla birleşmiş bir paylaşım oluşturmaya izin verilmez",
    "Invalid or untrusted SSL certificate" : "Geçersiz veya güvenilmeyen SSL sertifikası",
    "Could not authenticate to remote share, password might be wrong" : "Uzak paylaşım kimliği doğrulanamadı, parola hatalı olabilir",
    "Storage not valid" : "Depolama geçerli değil",
    "Couldn't add remote share" : "Uzak paylaşım eklenemedi",
    "Shared with you" : "Sizinle paylaşılmış",
    "Shared with others" : "Diğerleri ile paylaşılmış",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Nothing shared with you yet" : "Sizinle henüz hiçbir şey paylaşılmamış",
    "Files and folders others share with you will show up here" : "Sizinle paylaşılan dosya ve klasörler burada gösterilecek",
    "Nothing shared yet" : "Henüz hiçbir şey paylaşılmamış",
    "Files and folders you share will show up here" : "Paylaştığınız dosya ve klasörler burada gösterilecek",
    "No shared links" : "Paylaşılan bağlantı yok",
    "Files and folders you share by link will show up here" : "Bağlantı ile paylaştığınız dosya ve klasörler burada gösterilecek",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
    "Remote share" : "Uzak paylaşım",
    "Remote share password" : "Uzak paylaşım parolası",
    "Cancel" : "İptal",
    "Add remote share" : "Uzak paylaşım ekle",
    "You can upload into this folder" : "Bu dizine yükleme yapabilirsiniz",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote} üzerinde ownCloud (7 veya daha üstü) kurulumu bulunamadı",
    "Invalid ownCloud url" : "Geçersiz ownCloud adresi",
    "Shared by" : "Paylaşan",
    "Sharing" : "Paylaşım",
    "Share API is disabled" : "API paylaşımı devre dışı",
    "Wrong share ID, share doesn't exist" : "Yanlış kimlik paylaşımı, paylaşım mevcut değil",
    "Could not delete share" : "Paylaşım silinemedi",
    "Please specify a valid user" : "Lütfen geçerli bir kullanıcı belirtin",
    "Group sharing is disabled by the administrator" : "Topluluk paylaşımı yönetici yarafından devre dışı bırakıldı.",
    "Please specify a valid group" : "Lütfen geçerli bir topluluk belirtin",
    "Public link sharing is disabled by the administrator" : "Genel bağlantı paylaşımı yöneticiniz tarafından devre dışı bırakıldı .",
    "Public upload disabled by the administrator" : "Genel kaşıya yükleme yöneticiniz tarafından devre dışı bırakıldı .",
    "Public upload is only possible for publicly shared folders" : "Genel karşıya yüklemeler sadece genel paylaşılmış dosyalar için mümkündür.",
    "Invalid date, date format must be YYYY-MM-DD" : "Geçersiz tarih, tarih formatı YIL-AY-GÜN şeklinde olmalı",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Arka uç %s türündeki paylaşımlara izin vermediğinden %s paylaşımı başarısız",
    "Unknown share type" : "Bilinmeyen paylaşın türü",
    "Not a directory" : "Herhangi bir dizin yok",
    "Could not lock path" : "Yol bulunamadı",
    "Can't change permissions for public share links" : "Genel paylaşılan bağlantılar için izin değiştirilemiyor",
    "Wrong or no update parameter given" : "Verilen parametreler hatalı veya yok",
    "Cannot increase permissions" : "İzinler yükseltilemiyor",
    "A file or folder has been <strong>shared</strong>" : "Bir dosya veya klasör <strong>paylaşıldı</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Başka sunucudan</strong> bir dosya veya klasör paylaşıldı",
    "A public shared file or folder was <strong>downloaded</strong>" : "Herkese açık paylaşılan bir dosya veya klasör <strong>indirildi</strong>",
    "You received a new remote share %2$s from %1$s" : "%1$s kişisinden, %2$s uzak paylaşımını aldınız",
    "You received a new remote share from %s" : "%s kişisinden yeni bir uzak paylaşım aldınız",
    "%1$s accepted remote share %2$s" : "%1$s, %2$s uzak paylaşımını kabul etti",
    "%1$s declined remote share %2$s" : "%1$s, %2$s uzak paylaşımını reddetti",
    "%1$s unshared %2$s from you" : "%1$s, sizinle %2$s paylaşımını durdurdu",
    "Public shared folder %1$s was downloaded" : "Herkese açık paylaşılan klasör %1$s indirildi",
    "Public shared file %1$s was downloaded" : "Herkese açık paylaşılan dosya %1$s indirildi",
    "You shared %1$s with %2$s" : "%1$s dosyasını %2$s ile paylaştınız",
    "%2$s shared %1$s with %3$s" : "%2$s %3$s ile %1$s dosyasını paylaştı",
    "You removed the share of %2$s for %1$s" : "%1$s için %2$s paylaşımını kaldırdınız",
    "%2$s removed the share of %3$s for %1$s" : "%2$s, %1$s için %3$s paylaşımını kaldırdı",
    "You shared %1$s with group %2$s" : "%1$s dosyasını %2$s grubu ile paylaştınız",
    "%2$s shared %1$s with group %3$s" : "%2$s %3$s grubu ile %1$s dosyasını paylaştı",
    "You removed the share of group %2$s for %1$s" : "%1$s için %2$s grup paylaşımını kaldırdınız",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s, %1$s için %3$s grup paylaşımını kaldırdı",
    "%2$s shared %1$s via link" : "%2$s bağlantı ile %1$s dosyasını paylaştı",
    "You shared %1$s via link" : "Bağlantı ile %1$s paylaşımını yaptınız",
    "You removed the public link for %1$s" : "%1$s için paylaşım bağlantısını kaldırdınız",
    "%2$s removed the public link for %1$s" : "%2$s, %1$s için paylaşım bağlantısını kaldırdı",
    "Your public link for %1$s expired" : "%1$s için paylaşım bağlantınızın süresi doldu",
    "The public link of %2$s for %1$s expired" : "%1$s için %2$s paylaşım bağlantısının süresi doldu",
    "%2$s shared %1$s with you" : "%2$s sizinle %1$s dosyasını paylaştı",
    "%2$s removed the share for %1$s" : "%2$s, %1$s için paylaşımı kaldırdı",
    "Downloaded via public link" : "Herkese açık bağlantı ile indirildi",
    "Shared with %2$s" : "%2$s ile paylaşıldı",
    "Shared with %3$s by %2$s" : "%3$s ile %2$s tarafından paylaşıldı",
    "Removed share for %2$s" : "%2$s için paylaşım kaldırıldı",
    "%2$s removed share for %3$s" : "%2$s, %3$s için paylaşımı kaldırdı",
    "Shared with group %2$s" : "%2$s grubu ile paylaşıldı",
    "Shared with group %3$s by %2$s" : "%2$s tarafından %3$s grubu ile paylaşıldı",
    "Removed share of group %2$s" : "%2$s, grup paylaşımını kaldırdı",
    "%2$s removed share of group %3$s" : "%2$s, %3$s grup paylaşımını kaldırdı",
    "Shared via link by %2$s" : "%2$s tarafından bağlantı ile paylaşıldı",
    "Shared via public link" : "Herkese açık bağlantı ile paylaşıldı",
    "Removed public link" : "Paylaşım bağlantısı kaldırıldı",
    "%2$s removed public link" : "%2$s paylaşım bağlantısını kaldırdı",
    "Public link expired" : "Paylaşım bağlantısı süresi doldu",
    "Public link of %2$s expired" : "%2$s için paylaşım bağlantısı süresi doldu",
    "Shared by %2$s" : "%2$s tarafından paylaşıldı",
    "Shares" : "Paylaşımlar",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong. Try again." : "Parola hatalı. Yeniden deneyin.",
    "Password" : "Parola",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Name" : "Ad",
    "Share time" : "Paylaşma zamanı",
    "Sorry, this link doesn’t seem to work anymore." : "Üzgünüz, bu bağlantı artık çalışıyor gibi görünmüyor.",
    "Reasons might be:" : "Sebepleri şunlar olabilir:",
    "the item was removed" : "öge kaldırılmış",
    "the link expired" : "bağlantı süresi dolmuş",
    "sharing is disabled" : "paylaşım devre dışı",
    "For more info, please ask the person who sent this link." : "Daha fazla bilgi için bu bağlantıyı aldığınız kişi ile iletişime geçin.",
    "Add to your ownCloud" : "ownCloud'ınıza Ekleyin",
    "Download" : "İndir",
    "Download %s" : "İndir: %s",
    "Direct link" : "Doğrudan bağlantı"
},
"nplurals=2; plural=(n > 1);");
